@@ -20,8 +20,10 @@ import sys
 from os import makedirs, path
 from cmd import Cmd
 from subprocess import Popen, PIPE
+from threading import Timer
 
 from config import Config
+from utils import Catalogues
 
 STDOUT, STDERR = range(2)
 config = Config()
@@ -34,6 +36,13 @@ class Aptly(Cmd):
                       "Type 'help' for more information or 'quit' to exit.")
         self.known_commands = ['help', 'install', 'update', 'remove', 'prompt', 'set', 'quit']
         self.commands = []
+        self.ready = False
+
+        def get_catalogues():
+            self.catalogues = Catalogues()
+            self.ready = True
+
+        Timer(0, get_catalogues).start()
 
     def emptyline(self):
         pass
@@ -107,7 +116,7 @@ class Aptly(Cmd):
 
                 Popen(['dpkg', '-i', deb]).communicate()
 
-            Popen(' '.join(['apt-get', 'install'] + config.main['options'] + remote),
+            Popen(' '.join(['apt-get', 'install', config.main['options']] + remote),
                   shell=True).communicate()
 
 
@@ -155,10 +164,16 @@ class Aptly(Cmd):
         Popen(['apt-get', 'upgrade']).communicate()
 
     def do_list(self, packages):
-        for package in packages.split():
+        packages = packages.replace(',', ' ').split()
+
+        for package in packages:
             print "Files installed by '%s': " % package
             Popen(['dpkg', '-L', package]).communicate()
 
+    def do_search(self, phrase):
+        phrase = phrase.split() 
+        Popen(['apt-cache', 'search'] + phrase).communicate()
+        
     def help_list(self):
         print ("list [package1 package2]\n"
                "\tLists all files installed by named packages.")
@@ -213,7 +228,6 @@ class Aptly(Cmd):
                 config.main['options'].append("dir::cache::archives='%s'" % options[key])
             elif key == 'ask-first':
                 self.config.main[key] = options[key]
-                
     
     def help_set(self):
         print ("set miscellaneous options. Currently available options:\n"
